@@ -1,8 +1,5 @@
-(******************************************************************************)
-(* Lightweight thread library for OCaml
- * http://www.ocsigen.org/lwt
- * Interface Lwt_mon
- ******************************************************************************
+(* OCaml promise library
+ * https://ocsigen.org/lwt
  * Copyright (c) 2009, Metaweb Technologies, Inc.
  * All rights reserved.
  *
@@ -27,7 +24,19 @@
  * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
  * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
  * IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- ******************************************************************************)
+ *)
+
+(* This code is adapted from
+   https://web.archive.org/web/20101001215425/http://eigenclass.org:80/hiki/lightweight-threads-with-lwt. *)
+
+(* [Lwt_sequence] is deprecated – we don't want users outside Lwt using it.
+   However, it is still used internally by Lwt. So, briefly disable warning 3
+   ("deprecated"), and create a local, non-deprecated alias for
+   [Lwt_sequence] that can be referred to by the rest of the code in this
+   module without triggering any more warnings. *)
+[@@@ocaml.warning "-3"]
+module Lwt_sequence = Lwt_sequence
+[@@@ocaml.warning "+3"]
 
 type 'a t = {
   mutable mvar_contents : 'a option;
@@ -52,30 +61,42 @@ let create v =
 
 let put mvar v =
   match mvar.mvar_contents with
-    | None ->
-        begin match Lwt_sequence.take_opt_l mvar.readers with
-          | None ->
-              mvar.mvar_contents <- Some v
-          | Some w ->
-              Lwt.wakeup_later w v
-        end;
-        Lwt.return_unit
-    | Some _ ->
-        let (res, w) = Lwt.task () in
-        let node = Lwt_sequence.add_r (v, w) mvar.writers in
-        Lwt.on_cancel res (fun _ -> Lwt_sequence.remove node);
-        res
+  | None ->
+    begin match Lwt_sequence.take_opt_l mvar.readers with
+      | None ->
+        mvar.mvar_contents <- Some v
+      | Some w ->
+        Lwt.wakeup_later w v
+    end;
+    Lwt.return_unit
+  | Some _ ->
+    let (res, w) = Lwt.task () in
+    let node = Lwt_sequence.add_r (v, w) mvar.writers in
+    Lwt.on_cancel res (fun _ -> Lwt_sequence.remove node);
+    res
+
+let next_writer mvar =
+  match Lwt_sequence.take_opt_l mvar.writers with
+  | Some(v', w) ->
+    mvar.mvar_contents <- Some v';
+    Lwt.wakeup_later w ()
+  | None ->
+    mvar.mvar_contents <- None
+
+let take_available mvar =
+  match mvar.mvar_contents with
+  | Some v ->
+    next_writer mvar;
+    Some v
+  | None ->
+    None
 
 let take mvar =
+  match take_available mvar with
+  | Some v -> Lwt.return v
+  | None -> (Lwt.add_task_r [@ocaml.warning "-3"]) mvar.readers
+
+let is_empty mvar =
   match mvar.mvar_contents with
-    | Some v ->
-        begin match Lwt_sequence.take_opt_l mvar.writers with
-          | Some(v', w) ->
-              mvar.mvar_contents <- Some v';
-              Lwt.wakeup_later w ()
-          | None ->
-              mvar.mvar_contents <- None
-        end;
-        Lwt.return v
-    | None ->
-        Lwt.add_task_r mvar.readers
+  | Some _ -> false
+  | None -> true
