@@ -165,7 +165,7 @@ sig
   val add_link_flags : string list -> unit
 end =
 struct
-  let c_flags = ref []
+  let c_flags = ref ["-Wall"; "-fdiagnostics-color=always"]
   let link_flags = ref []
 
   let extend c_flags' link_flags' =
@@ -424,7 +424,7 @@ struct
         let code = {|
           #include <ev.h>
 
-          int main()
+          int main(void)
           {
               ev_default_loop(0);
               return 0;
@@ -452,7 +452,7 @@ struct
         let code = {|
           #include <pthread.h>
 
-          int main()
+          int main(void)
           {
               pthread_create(0, 0, 0, 0);
               return 0;
@@ -494,7 +494,7 @@ struct
       compiles context {|
         #include <sys/eventfd.h>
 
-        int main()
+        int main(void)
         {
             eventfd(0, 0);
             return 0;
@@ -511,7 +511,7 @@ struct
         #include <sys/types.h>
         #include <sys/socket.h>
 
-        int main()
+        int main(void)
         {
             struct msghdr msg;
             msg.msg_controllen = 0;
@@ -531,7 +531,7 @@ struct
         #define _GNU_SOURCE
         #include <sched.h>
 
-        int main()
+        int main(void)
         {
             sched_getcpu();
             return 0;
@@ -549,7 +549,7 @@ struct
         #define _GNU_SOURCE
         #include <sched.h>
 
-        int main()
+        int main(void)
         {
             sched_getaffinity(0, 0, 0);
             return 0;
@@ -562,7 +562,7 @@ struct
     #include <sys/types.h>
     #include <sys/socket.h>
 
-    int main()
+    int main(void)
     {
         struct |} ^ struct_name ^ {| cred;
         socklen_t cred_len = sizeof(cred);
@@ -612,7 +612,7 @@ struct
         #include <sys/types.h>
         #include <unistd.h>
 
-        int main()
+        int main(void)
         {
             uid_t euid;
             gid_t egid;
@@ -630,7 +630,7 @@ struct
       compiles context {|
         #include <unistd.h>
 
-        int main()
+        int main(void)
         {
             int (*fdatasyncp)(int) = fdatasync;
             fdatasyncp(0);
@@ -650,11 +650,10 @@ struct
         #include <netdb.h>
         #include <stddef.h>
 
-        int main()
+        int main(void)
         {
-            struct hostent *he;
-            struct servent *se;
-            he =
+            int x;
+            x =
               gethostbyname_r(
                 (const char*)NULL,
                 (struct hostent*)NULL,
@@ -662,9 +661,9 @@ struct
                 (int)0,
                 (struct hostent**)NULL,
                 (int*)NULL);
-            he =
+            x =
               gethostbyaddr_r(
-                (const char*)NULL,
+                (const void*)NULL,
                 (int)0,
                 (int)0,
                 (struct hostent*)NULL,
@@ -672,7 +671,7 @@ struct
                 (int)0,
                 (struct hostent**)NULL,
                 (int*)NULL);
-            se =
+            x =
               getservbyname_r(
                 (const char*)NULL,
                 (const char*)NULL,
@@ -680,7 +679,7 @@ struct
                 (char*)NULL,
                 (int)0,
                 (struct servent**)NULL);
-            se =
+            x =
               getservbyport_r(
                 (int)0,
                 (const char*)NULL,
@@ -688,20 +687,20 @@ struct
                 (char*)NULL,
                 (int)0,
                 (struct servent**)NULL);
-            pr =
+            x =
               getprotoent_r(
                 (struct protoent*)NULL,
                 (char*)NULL,
                 (int)0,
                 (struct protoent**)NULL);
-            pr =
+            x =
               getprotobyname_r(
                 (const char*)NULL,
                 (struct protoent*)NULL,
                 (char*)NULL,
                 (int)0,
                 (struct protoent**)NULL);
-            pr =
+            x =
               getprotobynumber_r(
                 (int)0,
                 (struct protoent*)NULL,
@@ -734,7 +733,7 @@ struct
         #define NON_R_GETHOSTBYNAME 1
         #endif
 
-        int main()
+        int main(void)
         {
         #if defined(NON_R_GETHOSTBYNAME) || defined(NON_R_GETHOSTBYNAME)
         #error "not available"
@@ -751,7 +750,7 @@ struct
     #include <sys/stat.h>
     #include <unistd.h>
 
-    int main() {
+    int main(void) {
         struct stat *buf;
         double a, m, c;
         a = (double)buf->st_a|} ^ projection ^ {|;
@@ -791,7 +790,7 @@ struct
         #include <unistd.h>
         #include <sys/mman.h>
 
-        int main()
+        int main(void)
         {
             int (*mincore_ptr)(const void*, size_t, char*) = mincore;
             return (int)(mincore_ptr == NULL);
@@ -809,7 +808,7 @@ struct
         #include <sys/socket.h>
         #include <stddef.h>
 
-        int main()
+        int main(void)
         {
             accept4(0, NULL, 0, 0);
             return 0;
