@@ -26,4 +26,17 @@
 #define NANOSEC(buf, field) 0.0
 #endif
 
+#include <caml/version.h>
+#if OCAML_VERSION < 50000
+#define CAML_NAME_SPACE
+#endif
+
+#if OCAML_VERSION < 41200
+#define Val_none Val_int(0)
+#define Some_val(v) Field(v, 0)
+#define Tag_some 0
+#define Is_none(v) ((v) == Val_none)
+#define Is_some(v) Is_block(v)
+#endif
+
 #endif // #ifndef _LWT_CONFIG_H_
