@@ -108,6 +108,8 @@ class virtual abstract = object(self)
   method timer_count = Lwt_sequence.length timers
 
   method fork = ()
+
+  method forwards_signal (_signum:int) = false
 end
 
 class type t = object
@@ -147,6 +149,8 @@ struct
   let devpoll = EV_DEVPOLL
   let port = EV_PORT
 
+  let equal = ( = )
+
   let name = function
     | EV_DEFAULT -> "EV_DEFAULT"
     | EV_SELECT -> "EV_SELECT"
@@ -160,6 +164,7 @@ struct
 end
 
 external ev_init : Ev_backend.t -> ev_loop = "lwt_libev_init"
+external ev_backend : ev_loop -> Ev_backend.t = "lwt_libev_backend"
 external ev_stop : ev_loop -> unit = "lwt_libev_stop"
 external ev_loop : ev_loop -> bool -> unit = "lwt_libev_loop"
 external ev_unloop : ev_loop -> unit = "lwt_libev_unloop"
@@ -175,6 +180,8 @@ class libev ?(backend=Ev_backend.default) () = object
   val loop = ev_init backend
   method loop = loop
 
+  method backend = ev_backend loop
+
   method private cleanup = ev_stop loop
 
   method iter block =
@@ -433,6 +440,7 @@ let readable_count () = !current#readable_count
 let writable_count () = !current#writable_count
 let timer_count () = !current#timer_count
 let fork () = !current#fork
+let forwards_signal n = !current#forwards_signal n
 
 module Versioned =
 struct
