@@ -11,14 +11,9 @@
 #include <caml/memory.h>
 #include <caml/mlvalues.h>
 #include <caml/unixsupport.h>
-#include <caml/version.h>
 
 #include "lwt_unix.h"
 
-#if OCAML_VERSION < 40600
-#define Bytes_val(x) String_val(x)
-#endif
-
 struct job_pread {
     struct lwt_unix_job job;
     HANDLE handle;
