@@ -320,7 +320,7 @@ let suite = suite "lwt_io" [
               exceptions_observed := !exceptions_observed + 1;
               Lwt.return_unit
             | exn ->
-              Lwt.fail exn) [@ocaml.warning "-4"]
+              Lwt.reraise exn) [@ocaml.warning "-4"]
       in
 
       let fd_r, fd_w = Lwt_unix.pipe () in
@@ -353,7 +353,7 @@ let suite = suite "lwt_io" [
       let filename = ref "." in
       let wrap f (filename', chan) = filename := filename'; f chan in
       let write_data chan = Lwt_io.write chan "test file content" in
-       let write_data_fail _ = Lwt.fail Dummy_error in
+      let write_data_fail _ = Lwt.fail Dummy_error in
       Lwt_io.with_temp_file (wrap write_data) ~prefix >>= fun _ ->
       let no_temps1 = not (Sys.file_exists !filename) in
        Lwt.catch
@@ -422,7 +422,7 @@ let suite = suite "lwt_io" [
       (function
       | Unix.Unix_error (Unix.EISDIR, "file_length", ".") ->
         Lwt.return_true
-      | exn -> Lwt.fail exn)
+      | exn -> Lwt.reraise exn)
   end;
 
   test "input channel of_bytes initial position"
